@@ -333,7 +333,7 @@ class Polynomial2D:
         tmp += c90*np.power(x1,9) + c81*np.power(x1,8)*x2 + c72*np.power(x1,7)*np.power(x2,2)
         tmp += c63*np.power(x1,6)*np.power(x2,3) + c54*np.power(x1,5)*np.power(x2,4) 
         tmp += c45*np.power(x1,4)*np.power(x2,5) + c36*np.power(x1,3)*np.power(x2,6) + c27*np.power(x1,2)*np.power(x2,7)
-        tmp += c18*np.power(x1,1)*np.power(x2,8) + c09*np.power(x1,0)*np.power(x2,9)
+        tmp += c18*x1*np.power(x2,8) + c09*np.power(x2,9)
         return tmp
     def _n10(self,x,c00,c10,c01,c20,c11,c02,
             c30,c21,c12,c03,c40,c31,c22,c13,c04,
